aboutsummaryrefslogtreecommitdiffstats
path: root/ui/ui.tabs.js
diff options
context:
space:
mode:
authorRichard Worth <rdworth@gmail.com>2008-11-14 03:00:16 +0000
committerRichard Worth <rdworth@gmail.com>2008-11-14 03:00:16 +0000
commit7ea535fa1df43e8259ab9987a0e8e08866cfb1f5 (patch)
treede1237434696e0f094e2cfb35d7fd5880b8a72bb /ui/ui.tabs.js
parented4f58c6d3c914baafaf07ab1d168e6c199b8693 (diff)
downloadjquery-ui-7ea535fa1df43e8259ab9987a0e8e08866cfb1f5.tar.gz
jquery-ui-7ea535fa1df43e8259ab9987a0e8e08866cfb1f5.zip
fixed #3578 - ALL CODE: e, ui should be changed to event, ui
Diffstat (limited to 'ui/ui.tabs.js')
-rw-r--r--ui/ui.tabs.js8
1 files changed, 4 insertions, 4 deletions
diff --git a/ui/ui.tabs.js b/ui/ui.tabs.js
index 1a878be02..d75b2ab9f 100644
--- a/ui/ui.tabs.js
+++ b/ui/ui.tabs.js
@@ -217,7 +217,7 @@ $.widget("ui.tabs", {
// attach tab event handler, unbind to avoid duplicates from former tabifying...
this.$tabs.unbind('.tabs').bind(o.event + '.tabs', function() {
//var trueClick = e.clientX; // add to history only if true click occured, not a triggered click
var $li = $(this).parents('li:eq(0)'),
$hide = self.$panels.filter(':visible'),
$show = $(self._sanitizeSelector(this.hash));
@@ -435,7 +435,7 @@ $.widget("ui.tabs", {
try {
o.ajaxOptions.success(r, s);
}
- catch (e) {}
+ catch (event) {}
// This callback is required because the switch has to take
// place after loading has completed. Call last in order to
@@ -531,8 +531,8 @@ $.extend($.ui.tabs.prototype, {
}, ms);
}
- function stop(e) {
- if (!e || e.clientX) { // only in case of a true click
+ function stop(event) {
+ if (!event || event.clientX) { // only in case of a true click
clearInterval(self.rotation);
}
}
@@ -217,7 +217,7 @@ $.widget("ui.tabs", {
// attach tab event handler, unbind to avoid duplicates from former tabifying...
this.$tabs.unbind('.tabs').bind(o.event + '.tabs', function() {
- //var trueClick = e.clientX; // add to history only if true click occured, not a triggered click
+ //var trueClick = event.clientX; // add to history only if true click occured, not a triggered click
var $li = $(this).parents('li:eq(0)'),
$hide = self.$panels.filter(':visible'),